@@ -8,6 +8,8 @@ let _inspectingTabId;
 // vivaldiInspectTabId is set on the contentWindow in the document loading
 function init() {
   _theWebview = document.createElement("webview");
+  _theWebview.name = "vivaldi-devtools-main";
+
   _theWebview.inspect_tab_id = _inspectingTabId = vivaldiInspectTabId;
   const webviewdiv = document.getElementById("webviewdiv");
   webviewdiv.appendChild(_theWebview);
@@ -28,6 +30,12 @@ function attachWebViewListeners() {
   _theWebview.addEventListener("dialog", onJavascriptDialog);
 }
 
+function detachWebViewListeners() {
+  _theWebview.removeEventListener("newwindow", onNewWindow);
+  _theWebview.removeEventListener("close", onClose);
+  _theWebview.removeEventListener("dialog", onJavascriptDialog);
+}
+
 function attachDevtoolsListeners() {
   vivaldi.devtoolsPrivate.onDockingStateChanged.addListener(
     onDockingStateChanged
@@ -36,9 +44,19 @@ function attachDevtoolsListeners() {
   vivaldi.devtoolsPrivate.onActivateWindow.addListener(onActivateWindow);
 }
 
-function closeWindow() {
-  webviewdiv.removeChild(_theWebview);
-  window.close();
+function detachDevtoolsListeners() {
+  vivaldi.devtoolsPrivate.onDockingStateChanged.removeListener(
+    onDockingStateChanged
+  );
+  vivaldi.devtoolsPrivate.onClosed.removeListener(onDevtoolsClosed);
+  vivaldi.devtoolsPrivate.onActivateWindow.removeListener(onActivateWindow);
+}
+
+async function closeWindow() {
+  detachWebViewListeners();
+  detachDevtoolsListeners();
+  const winId = await vivaldi.windowPrivate.getCurrentId();
+  chrome.windows.remove(winId);
 }
 
 function onDevtoolsClosed(tabId) {
@@ -49,8 +67,7 @@ function onDevtoolsClosed(tabId) {
 
 function onActivateWindow(tabId) {
   if (tabId === _inspectingTabId) {
-    const thisAppWindow = chrome.app.window.current();
-    thisAppWindow.focus();
+    window.focus();
     _theWebview.focus();
   }
 }
@@ -61,9 +78,9 @@ function onDockingStateChanged(tabId, dockingState) {
   }
 }
 
-function onClose(event) {
-  const thisAppWindow = chrome.app.window.current();
-  thisAppWindow.close();
+async function onClose(event) {
+  const winId = await vivaldi.windowPrivate.getCurrentId();
+  chrome.windows.remove(winId);
 }
 
 function onNewWindow(event) {
